<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapEnd</name>
    <message>
        <location filename="../SnapEndInit.js" line="+2"/>
        <source>&amp;End</source>
        <translatorcomment>--google--
Punkty &amp;końcowe
Za&amp;kończenia interpunkcyjne</translatorcomment>
        <translation>&amp;Koniec</translation>
    </message>
</context>
</TS>
